var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Image',
	table: 'Table',
	link: 'Link',
	link_insert: 'Insert link ...',
	unlink: 'Unlink',
	styles: 'Styles',
	paragraph: 'Paragraph',
	quote: 'Quote',
	code: 'Code',
	header1: 'Header 1',
	header2: 'Header 2',
	header3: 'Header 3',
	header4: 'Header 4',
	format: 'Format',
	bold:  'Bold',
	italic: 'Italic',
	superscript: 'Superscript',
	strikethrough: 'Strikethrough',
	fontcolor: 'Font color',
	backcolor: 'Back color',
	removeformat: 'Remove format',
	cleanstyles: 'Clean styles',
	lists: 'Lists',
	unorderedlist: 'Unordered list',
	orderedlist: 'Ordered list',	
	outdent: 'Outdent',
	indent: 'Indent',
	redo: 'Redo',
	undo: 'Undo',
	cut: 'Cut',
	cancel: 'Cancel',	
	insert: 'Insert',
	save: 'Save',	
	_delete: 'Delete',
	insert_table: 'Insert table',		
	insert_row_above: 'Add row above',
	insert_row_below: 'Add row below',
	insert_column_left: 'Add column left',
	insert_column_right: 'Add column right',									
	delete_column: 'Delete column',									
	delete_row: 'Delete row',									
	delete_table: 'Delete table',
	Rows: 'Rows',
	Columns: 'Columns',	
	add_head: 'Add head',
	delete_head: 'Delete head',	
	title: 'Title',
	image_view: 'View image',
	image_position: 'Position',
	none: 'none',
	left: 'left',
	right: 'right',
	image_web_link: 'Image web link',
	text: 'Text',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Video embed code',
	file: 'File',	
	upload: 'Upload',
	download: 'Download',
	choose: 'Choose',
	or_choose: 'Or choose',
	drop_file_here: 'Drop file here',
	align_left:	'Align left',	
	align_center: 'Align center',
	align_right: 'Align right',
	align_justify: 'Justify',
	horizontalrule: 'Horizontal rule',
	fullscreen: 'Fullscreen',
	deleted: 'Deleted',
	none: 'None',
	anchor: 'Anchor'
};
