var RLANG = {
	html: 'HTML',
	video: 'Видео',
	image: 'Изображение',
	table: 'Таблица',
	link: 'Връзка',
	link_insert: 'Вкарай връзка ...',
	unlink: 'Премахни връзка',
	styles: 'Стилове',
	paragraph: 'Параграф',
	quote: 'Цитат',
	code: 'Код',
	header1: 'Заглавие 1',
	header2: 'Заглавие 2',
	header3: 'Заглавие 3',
	header4: 'Заглавие 4',
	format: 'Форматиране',
	bold:  'Удебели',
	italic: 'Наклони',
	superscript: 'Горен индекс',
	strikethrough: 'Зачеркни',
	fontcolor: 'Цвят на текста',
	backcolor: 'Цвят на фона',
	removeformat: 'Премахни форматирането',
	cleanstyles: 'Изчисти стиловете',
	lists: 'Списъци',
	unorderedlist: 'Неподреден списък',
	orderedlist: 'Подреден списък',
	outdent: 'Вкарай навътре',
	indent: 'Изкарай навън',
	redo: 'Повтори',
	undo: 'Отмени',
	cut: 'Изрежи',
	cancel: 'Отказ',
	insert: 'Вкарай',
	save: 'Запази',
	_delete: 'Премахни',
	insert_table: 'Вкарай таблица',
	insert_row_above: 'Добави ред отгоре',
	insert_row_below: 'Добави ред отдолу',
	insert_column_left: 'Добави колона отляво',
	insert_column_right: 'Добави колона отдясно',
	delete_column: 'Премахни колоната',
	delete_row: 'Премахни реда',
	delete_table: 'Премахни таблицата',
	Rows: 'Редове',
	Columns: 'Колони',
	add_head: 'Добави заглавен ред',
	delete_head: 'Премахни заглавен ред',
	title: 'Заглавие',
	image_view: 'Виж изображението',
	image_position: 'Позиция',
	left: 'ляво',
	right: 'дясно',
	image_web_link: 'Уеб връзка',
	text: 'Текст',
	mailto: 'Имейл',
	web: 'Адрес',
	video_html_code: 'Код за вграждане на видео',
	file: 'Файл',
	upload: 'Качи',
	download: 'Свали',
	choose: 'Избор',
	or_choose: 'Или избери',
	drop_file_here: 'Провлачете файлове тук',
	align_left:	'Подравни в ляво',
	align_center: 'Центрирай',
	align_right: 'Подравни в дясно',
	align_justify: 'Подравни двустранно',
	horizontalrule: 'Хоризонтална линия',
	fullscreen: 'Цял екран',
	deleted: 'Зачеркни',
	none: 'Няма',
	anchor: 'Връзка'
};
