.redactor_box {
	position: relative;
	border: 1px solid #ddd;	
	line-height: 0;
}
.redactor_box, .redactor_box textarea {
	background-color: #fff;
}
.redactor_box iframe {
	outline: none;	
	width: 100%;
	background: #fff;
	display: block;
	overflow: auto;
}
.redactor_box textarea {
	font-family: Menlo, Monaco, monospace, sans-serif;
	font-size: 13px;
	overflow: auto;
	resize: none;
	margin: 0;
	padding: 0;
	display: block;
	position: relative;
	z-index: 1004; 
	outline: none;	
	border: none;
	width: 100%;
}
.redactor_box textarea:focus {
	outline: none !important;
	border: none !important;
	box-shadow: none;
}

/*
	Fuulscreen
*/
body .redactor_box_fullscreen {
    border: medium none !important;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 100%;
    z-index: 2000;
}

/*
	TOOLBAR
*/
.redactor_toolbar {
	position: relative;
	left: 0;
	top: 0;
	margin: 0 !important;
	padding: 0 !important;
	line-height: 0 !important;
	list-style: none;
	font-size: 0;
	background: #f2f2f2;
	background: -moz-linear-gradient(top,  #f5f5f5 0%, #ddd 100%);
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f5f5f5), color-stop(100%,#ddd));
	background: -webkit-linear-gradient(top,  #f5f5f5 0%,#ddd 100%);
	background: -o-linear-gradient(top,  #f5f5f5 0%,#ddd 100%);
	background: -ms-linear-gradient(top,  #f5f5f5 0%,#ddd 100%);
	background: linear-gradient(top,  #f5f5f5 0%,#ddd 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f5f5f5', endColorstr='#dddddd',GradientType=0 );
	overflow: hidden;	
	border-bottom: 1px solid #bbb;
}
.redactor_toolbar li {
	float: left !important;
	padding: 3px 1px;
	padding-right: 0;
	list-style-type: none;	
}
.redactor_toolbar li.redactor_separator {
	float: left;		
	height: 34px;
	border-left: 1px solid #d7d7d7;
	border-right: 1px solid #eee;	
	padding: 0;
	margin: 0 2px 0 3px;
}
li.redactor_toolbar_right {
	float: none;
	float: right !important;
	padding: 2px 0;
	padding-right: 1px !important;
}
.redactor_toolbar li a, .redactor_toolbar li a span {
	width: 25px;
	height: 26px;
}	
.redactor_toolbar li a {
	border: 1px solid transparent;
	* border: 1px solid #eee; 
	display: block;
	line-height: 0;
	font-size: 0;
	cursor: pointer;
	zoom: 1;
	text-decoration: none;
}	
.redactor_toolbar li a span {
	display: block;
	text-indent: -9999px;
	background: url(../img/icons.png) no-repeat top left;
}
	
.redactor_toolbar li a:hover {
	border-color: #98a6ba;
	background-color: #dde4ef;
}
.redactor_toolbar li a:active, .redactor_toolbar li a.act {
	border-color: #b5b5b5;
	background-color: #e8e8e8;
}


/*
	BUTTONS
	step 25px
*/
body .redactor_toolbar li a.redactor_btn_html span				  { background-position: 0; }
body .redactor_toolbar li a.redactor_btn_styles span			  { background-position: -25px; }
body .redactor_toolbar li a.redactor_btn_bold span				  { background-position: -50px; }
body .redactor_toolbar li a.redactor_btn_italic span			  { background-position: -75px; }
body .redactor_toolbar li a.redactor_btn_deleted span		 	  { background-position: -550px; }		
body .redactor_toolbar li a.redactor_btn_insertunorderedlist span { background-position: -100px; }		
body .redactor_toolbar li a.redactor_btn_insertorderedlist span   { background-position: -125px; }
body .redactor_toolbar li a.redactor_btn_outdent span	 		  { background-position: -150px; }
body .redactor_toolbar li a.redactor_btn_indent span		 	  { background-position: -175px; }
body .redactor_toolbar li a.redactor_btn_image span		 		  { background-position: -200px; }
body .redactor_toolbar li a.redactor_btn_video span		 		  { background-position: -225px; }
body .redactor_toolbar li a.redactor_btn_file span		 		  { background-position: -250px; }	
body .redactor_toolbar li a.redactor_btn_table span		 		  { background-position: -275px; }
body .redactor_toolbar li a.redactor_btn_link span		 		  { background-position: -300px; }
body .redactor_toolbar li a.redactor_btn_fontcolor span		 	  { background-position: -325px; }
body .redactor_toolbar li a.redactor_btn_backcolor span		 	  { background-position: -350px; }
body .redactor_toolbar li a.redactor_btn_justifyleft span		  { background-position: -375px; }
body .redactor_toolbar li a.redactor_btn_justifycenter span		  { background-position: -400px; }
body .redactor_toolbar li a.redactor_btn_justifyright span		  { background-position: -425px; }
body .redactor_toolbar li a.redactor_btn_justify span		 	  { background-position: -450px; }
body .redactor_toolbar li a.redactor_btn_horizontalrule span 	  { background-position: -475px; }
body .redactor_toolbar li a.redactor_btn_fullscreen span		  { background-position: -500px; }							
body .redactor_toolbar li a.redactor_btn_normalscreen span		  { background-position: -525px !important; }	


/*
	RESIZER
*/
.redactor_resizer {
	background-color: #f5f5f5;
	padding-top: 2px;
	line-height: 4px;
	font-size: 12px;
	color: #ddd;
	text-align: center;
	text-shadow: 0 -1px 0 #aaa;
	cursor: s-resize;
}



/*
	DROPDOWN
*/
.redactor_dropdown {
	top: 28px;
	left: 0;
	z-index: 2004;
	position: absolute;
	width: 200px;
	background-color: #fff;
	border: 1px solid #ccc;
	font-size: 13px;
	-webkit-box-shadow: 0 2px 4px #ccc;
	-moz-box-shadow: 0 2px 4px #ccc;	
	box-shadow: 0 2px 4px #ccc;	
	line-height: 21px;	
	padding: 10px;	
}
.redactor_separator_drop {
	border-top: 1px solid #ddd;;
	padding: 0 !important;
	line-height: 0;
	font-size: 0;
}
.redactor_dropdown a {
	display: block;
	color: #000;
	padding: 3px 5px;
	text-decoration: none;
}
.redactor_dropdown a:hover {
	color: #444 !important;
	text-decoration: none;
	background-color: #dde4ef;
}		

/* ColorPicker */
.redactor_color_link {
	padding: 0 !important;
	width: 15px !important;
	height: 15px !important;
	float: left !important;
	border: 2px solid #fff !important;
	font-size: 0;
}
.redactor_color_none {
	font-size: 11px;
}



/* MODAL */
#redactor_modal_overlay {
	position: fixed;
	margin: auto;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 50000;
	
	-ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
	filter:alpha(opacity=80);
	opacity: 0.80;
	
	background-color: #fff !important;
}

#redactor_modal {
	background-color: #fff;
	padding: 0;
	position: fixed;
	top: 50%;
	left: 50%;
	
	box-shadow: 0px 5px 20px #999;
	-webkit-box-shadow: 0 5px 20px #999; 
  	-moz-box-shadow: 0 5px 20px #999;	
  	
  	-webkit-border-radius: 8px;
  	-moz-border-radius: 8px;
  	border-radius: 8px;  	  	
  		
  	z-index: 50001;	
	font-family: Helvetica, Arial, Verdana, Tahoma, sans-serif;      
	font-size: 12px !important;	
	color: #000;
}
#redactor_modal_header {
	padding: 15px;
	font-size: 18px;
	
	border-radius: 8px 8px 0 0;
	
	font-weight: bold;
	background-color: #f6f6f6;
	border-bottom: 1px solid #ddd;
}
#redactor_modal_inner {
	padding: 15px 30px 20px 30px;
}
#redactor_modal_close {
	position: absolute;
	right: 0px;
	top: 11px;
	font-size: 24px;
	width: 30px;
	height: 30px;
	color: #999;
	cursor: pointer;
}
#redactor_modal_close:hover {
	color: #000;
}
#redactor_modal_footer {
	overflow: hidden;
	padding-top: 20px;
}
#redactor_modal label {
	margin: 10px 0 0 0 !important;
	padding: 0 !important;
	float: none !important;
	display: block !important;
}
#redactor_btn_modal_close {
	color: #777;
	font-size: 11px !important;
}
.redactor_input  {
	width: 99%;
	font-size: 14px;
}
#redactor_image_box {
	height: 270px; 
	overflow: auto; 
	margin-bottom: 10px;
}
#redactor_image_box img {
	margin-right: 10px;
	margin-bottom: 10px;
	cursor: pointer;
}
#redactor_tabs {
	margin-bottom: 18px;
}
#redactor_tabs a {
	display: inline-block;
	border: 1px solid #ddd;
	padding: 4px 14px;
	font-size: 12px;
	text-decoration: none;
	color: #000;
	line-height: 1;
	-webkit-border-radius: 10px;
	-moz-border-radius: 10px;
	border-radius: 10px;		
}
#redactor_tabs a:hover, #redactor_tabs a.redactor_tabs_act {
	background-color: #eee;
	color: #777 !important;
	text-decoration: none !important;
}
.redactor_btns_box {
	float: right;
	padding: 6px 16px;
	background-color: #eee;
  	-webkit-border-radius: 5px;
  	-moz-border-radius: 5px;
  	border-radius: 5px;  	
}

/* Drag and Drop Area */
.redactor_droparea {
	position: relative;
    width: 100%;
    margin: auto;	
    margin-bottom: 5px;
}
.redactor_droparea .redactor_dropareabox {    
	z-index: 1;
	position: relative;
    text-align: center;    
    width: 99%;
    padding: 60px 0;
    border: 2px dashed #bbb;
}
.redactor_droparea .redactor_dropareabox, .redactor_dropalternative {
    color: #777;
    font-size: 12px;
}
.redactor_dropalternative {
	margin: 4px 0 2px 0;
}
.redactor_dropareabox.hover {
    background: #efe3b8;
    border-color: #aaa;
}
.redactor_dropareabox.error {
    background: #f7e5e5;
    border-color: #dcc3c3;
}
.redactor_dropareabox.drop {
    background: #f4f4ee;
    border-color: #e0e5d6;
}
