var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Immagine',
	table: 'Tabella',
	link: 'Collegamento',
	link_insert: 'Inserisci un collegamento ...',
	unlink: 'Rimuovi il collegamento',
	styles: 'Stili',
	paragraph: 'Paragrafo',
	quote: 'Quote',
	code: 'Codice',
	header1: 'H1',
	header2: 'H2',
	header3: 'H3',
	header4: 'H4',
	format: 'Formatta',
	bold:  'Grassetto',
	italic: 'Corsivo',
	superscript: 'Superscript',
	strikethrough: 'Strikethrough',
	fontcolor: 'Colore del font',
	backcolor: 'Colore di sfondo',
	removeformat: 'Rimuovi formattazione',
	cleanstyles: 'Ripulisci stili',
	lists: 'Elenco',
	unorderedlist: 'Elenco puntato',
	orderedlist: 'Elenco numerato',	
	outdent: 'Outdent',
	indent: 'Indent',
	redo: 'Ripeti',
	undo: 'Annulla',
	cut: 'Taglia',
	cancel: 'Cancella',	
	insert: 'Inserisci',
	save: 'Salva',	
	_delete: 'rimuovi',
	insert_table: 'Inserisci tabella',		
	insert_row_above: 'Inserisci una riga sopra',
	insert_row_below: 'Inserisci una riga sotto',
	insert_column_left: 'Aggiungi una colonna a sinistra',
	insert_column_right: 'Aggiungi una colonna a destra',									
	delete_column: 'Cancella colonna',									
	delete_row: 'Cancella riga',									
	delete_table: 'Cancella tabella',
	Rows: 'Righe',
	Columns: 'Colonne',	
	add_head: 'Aggiungi head',
	delete_head: 'Cancella head',	
	title: 'Titolo',
	image_view: 'Visualizza immagine',
	image_position: 'Posizione',
	none: 'Nessun',
	left: 'Sinistra',
	right: 'Destra',
	image_web_link: 'URL immagine',
	text: 'Testo',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Embed code filmato',
	file: 'File',	
	upload: 'Upload',
	download: 'Download',
	choose: 'Scegli',
	or_choose: 'O Scegli',
	drop_file_here: 'Trascina il file qui',
	align_left:	'Allinea a sinistra',	
	align_center: 'Allinea al centro',
	align_right: 'Allinea a destra',
	align_justify: 'Giustifica',
	horizontalrule: 'Orizzonatale',
	fullscreen: 'Schermo intero',
	deleted: 'Cancellato',
	none: 'Nessun',
	anchor: 'Ancora'
};
