var RLANG = {
	html: 'Źródło',
	video: 'Wideo',
	image: 'Obrazek',
	table: 'Tabela',
	link: 'Link',
	link_insert: 'Wstaw link ...',
	unlink: 'Usuń link',
	styles: 'Style',
	paragraph: 'Zwykły tekst',
	quote: 'Cytat',
	code: 'Kod źródłowy',
	header1: 'Nagłówek 1',
	header2: 'Nagłówek 2',
	header3: 'Nagłówek 3',
	header4: 'Nagłówek 4',	
	format: 'Format',
	bold:  'Pogrubiony',
	italic: 'Pochylony',
	superscript: 'Indeks górny',
	strikethrough: 'Przekreślenie',
	fontcolor: 'Kolor tekstu',
	backcolor: 'Kolor tła',
	removeformat: 'Wyczyść formatowanie',
	cleanstyles: 'Wyczyść style MS Word',
	lists: 'Wypunktowanie i numeracja',
	unorderedlist: 'Wypunktowanie',
	orderedlist: 'Numeracja',
	outdent: 'Zwiększ wcięcie',
	indent: 'Zmniejsz wcięcie',
	redo: 'Ponów',
	undo: 'Cofnij',
	cut: 'Wytnij',
	cancel: 'Anuluj',
	insert: 'Wstaw',
	save: 'Zachowaj',
	_delete: 'Usuń',
	insert_table: 'Wstaw tabele',
	insert_row_above: 'Dodaj wiersz na górze',
	insert_row_below: 'Dodaj wiersz na dole',
	insert_column_left: 'Dodaj kolumnę po lewej',
	insert_column_right: 'Dodaj kolumnę po prawej',
	delete_column: 'Usuń kolumnę',
	delete_row: 'Usuń wiersz',
	delete_table: 'Usuń tabele',
	Rows: 'Wiersze',
	Columns: 'Kolumny',
	add_head: 'Dodaj nagłówek',
	delete_head: 'Usuń nagłówek',
	title: 'Wskazówka',
	image_view: 'Pokaż obrazek',
	image_position: 'Obramowanie',
	none: 'nie ma',
	left: 'od lewej',
	right: 'od prawej',
	image_web_link: 'albo link do obrazku',
	text: 'Tekst',
	mailto: 'Poczta e-mail',
	web: 'URL',
	video_html_code: 'Kod źródłowy pliku wideo',
	file: 'Plik',
	upload: 'Wgraj na serwer',
	download: 'Pobierz',
	choose: 'Choose',
	or_choose: 'Or choose',
	drop_file_here: 'Drop file here',
	align_left:	'Align left',	
	align_center: 'Align center',
	align_right: 'Align right',
	align_justify: 'Justify',
	horizontalrule: 'Horizontal rule',
	fullscreen: 'Fullscreen',
	deleted: 'Deleted',
	none: 'None'						
};