var RLANG = {
	html: 'HTML кods',
	video: 'Video',
	image: 'Attēls',
	table: 'Tabula',
	link: 'Saite',
	link_insert: 'Iekļaut saiti ...',
	unlink: 'Noņemt saiti',
	styles: 'Stili',
	paragraph: 'Vienkāršs teksts',
	quote: 'Citāts',
	code: 'Kods',
	header1: 'Virsraksts 1',
	header2: 'Virsraksts 2',
	header3: 'Virsraksts 3',
	header4: 'Virsraksts 4',		
	format: 'Formāts',
	bold:  'Pustrekns',
	italic: 'Slīps',
	superscript: 'Augšraksts',
	strikethrough: 'Nosvītrots',
	fontcolor: 'Teksta krāsa',
	backcolor: 'Fona krāsa',
	removeformat: 'Noņemt stilus',
	cleanstyles: 'Noņemt stilus MS Word',
	lists: 'Saraksti',
	unorderedlist: 'Parasts saraksts',
	orderedlist: 'Numurēts saraksts',	
	outdent: 'Samazināt atkāpi',
	indent: 'Palielināt atkāpi',
	redo: 'Atatsaukt',
	undo: 'Atsaukt',
	cut: 'Izgriezt',
	cancel: 'Atcelt',	
	insert: 'Iespraust',
	save: 'Saglabāt',	
	_delete: 'Dzēst',
	insert_table: 'Iespraust tabulu',
	insert_row_above: 'Pievienot rindu no augšas',
	insert_row_below: 'Pievienot rindu no apakšas',
	insert_column_left: 'Pievienot stabiņu no kreisās puses',
	insert_column_right: 'Pievienot stabiņu no labās puses',									
	delete_column: 'Dzēst stabiņu',									
	delete_row: 'Dzēst rindu',									
	delete_table: 'Dzēst tabulu',
	Rows: 'Rindas',
	Columns: 'Stabiņi',	
	add_head: 'Pievienot virsrakstu',
	delete_head: 'Dzēst virsrakstu',	
	title: 'Uzvedne',
	image_view: 'Apskatīt attēlu',
	image_position: 'Аttēla apliece',
	none: 'nav',
	left: 'pa kreisi',
	right: 'pa labi',
	image_web_link: 'vai saite uz attēlu',
	text: 'Teksts',
	mailto: 'E-pasts',
	web: 'URL',
	video_html_code: 'Videoklipu kods',
	file: 'Fails',
	upload: 'Augšupielāde',
	download: 'Lejupielāde',
	choose: 'Izvēlieties',
	or_choose: 'Vai izvēlieties',
	drop_file_here: 'Vilkt failu uz šejieni',
	align_left:	'Izlīdzināt pa labi',
	align_center: 'Izlīdzināt pa kreisi',
	align_right: 'Izlīdzināt pret centru',
	align_justify: 'Izlīdzināt malas',
	horizontalrule: 'Horizontāla līnija',
	fullscreen: 'Pa visu ekrānu',
	none: 'None'	
};