var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Bilder',
	table: 'Tabelle',
	link: 'Link',
	link_insert: 'Link einfügen ...',
	unlink: 'Link entfernen',
	styles: 'Styles',
	paragraph: 'Absatz',
	quote: 'Zitat',
	code: 'Code',
	header1: 'Kopfzeile 1',
	header2: 'Kopfzeile 2',
	header3: 'Kopfzeile 3',
    header4: 'Kopfzeile 4',
	format: 'Format',
	bold:  'Fett',
	italic: 'Kursiv',
	superscript: 'Hochgestellt',
	strikethrough: 'Strikethrough',
	fontcolor: 'Schriftfarbe',
	backcolor: 'Texthervorhebungsfarbe',
	removeformat: 'Formatierung löschen',
	cleanstyles: 'Styles säubern',
	lists: 'Lists',
	unorderedlist: 'Aufzählungszeichen',
	orderedlist: 'Nummerierung',	
	outdent: 'Einzug verkleinern',
	indent: 'Einzug vergrößern',
	redo: 'Wiederholen',
	undo: 'Rückgängig',
	cut: 'Ausschneiden',
	cancel: 'Abbrechen',	
	insert: 'Einfügen',
	save: 'Speichern',	
	_delete: 'Löschen',
	insert_table: 'Tabelle einfügen',		
	insert_row_above: 'Zeilen oberhalb einfügen',
	insert_row_below: 'Zeilen unterhalb einfügen',
	insert_column_left: 'Spalten links einfügen',
	insert_column_right: 'Spalten rechts einfügen',									
	delete_column: 'Spalten löschen',									
	delete_row: 'Zeilen löschen',									
	delete_table: 'Tabelle löschen',
	Rows: 'Zeilen',
	Columns: 'Spalten',	
	add_head: 'Titel einfügen',
	delete_head: 'Titel entfernen',	
	title: 'Title',
	image_view: 'Bider',
	image_position: 'Textumbruch',
	none: 'Keine',
	left: 'Links',
	right: 'Rechts',
	image_web_link: 'Bilder Link',
	text: 'Text',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Video embed code',
	file: 'Datei',	
	upload: 'laden',
	download: 'Download',
	choose: 'Auswählen',
	or_choose: 'Oder, wählen Sie',
	drop_file_here: 'Ziehen Sie eine Datei hier',
	align_left:	'Linksbündig',	
	align_center: 'Mitte',
	align_right: 'Rechtsbündig',
	align_justify: 'Setzt den Text der Breite',
	horizontalrule: 'Horizontale Linie',
	fullscreen: 'Vollbild',
	deleted: 'Durchgestrichen',
	anchor: 'Anker'    	
};