var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Fotografi',
	table: 'Tabel&euml;',
	link: 'Link',
	link_insert: 'Lidh linq ...',
	unlink: 'Hiq linkun',
	styles: 'Stilet',
	paragraph: 'Paragraf',
	quote: 'Kuot&euml;',
	code: 'Kod',
	header1: 'Header 1',
	header2: 'Header 2',
	header3: 'Header 3',
	header4: 'Header 4',
	format: 'Formati',
	bold:  'Te trasha / Bold',
	italic: 'Kursive / Italic',
	superscript: 'Superscript',
	strikethrough: 'Strikethrough',
	fontcolor: 'Ngjyra e shkronjave',
	backcolor: 'Ngjyra e mbrapavis&euml; s&euml; shkronjave',
	removeformat: 'Fshije formatin',
	cleanstyles: 'Pastro stilet',
	lists: 'Listat',
	unorderedlist: 'Liste pa renditje',
	orderedlist: 'Liste me renditje',	
	outdent: 'Outdent',
	indent: 'Indent',
	redo: 'Rib&euml;j',
	undo: 'Zhb&euml;j',
	cut: 'Cut',
	cancel: 'Anulo',	
	insert: 'Insert',
	save: 'Ruaje',	
	_delete: 'Fshije',
	insert_table: 'Shto tabel&euml;',		
	insert_row_above: 'Shto rresht sip&euml;r',
	insert_row_below: 'Shto rresht p&euml;rfundi',
	insert_column_left: 'Shto kolon&euml; majtas',
	insert_column_right: 'Shto kolon&euml; djathtas',									
	delete_column: 'Fshije kolon&euml;n',									
	delete_row: 'Fshije rreshtin',									
	delete_table: 'Fshije tabel&euml;n',
	Rows: 'Rreshta',
	Columns: 'Kolona',	
	add_head: 'Shto titujt e tabel&euml;s',
	delete_head: 'Fshije titujt e tabel&euml;s',	
	title: 'Titulli',
	image_view: 'Shiko fotografin&euml;',
	image_position: 'Pozita',
	none: 'Normale',
	left: 'Majtas',
	right: 'Djathtas',
	image_web_link: 'Linku i fotografis&euml; n&euml; internet',
	text: 'Teksti',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Video embed code',
	file: 'Fajll',	
	upload: 'Ngarko',
	download: 'Shkarko',
	choose: 'Zgjedh',
	or_choose: 'Ose zgjedh',
	drop_file_here: 'Gjuaje fajllin k&euml;tu',
	align_left:	'Rreshtoje majtas',	
	align_center: 'Rreshtoje n&euml; mes',
	align_right: 'Rreshtoje djathtas',
	align_justify: 'Rreshtoje t&euml; gjithin njejt',
	horizontalrule: 'Viz&euml; horizontale',
	fullscreen: 'Pamje e plot&euml;',
	deleted: 'E fshir&euml;',
	none: 'None',
	anchor: 'Anchor'
};
