var RLANG = {
	html: 'HTML',
	video: 'Videó',
	image: 'Kép',
	table: 'Tábla',
	link: 'Link',
	link_insert: 'Link beszúrás ...',
	unlink: 'Link megszüntetés',
	styles: 'Stílusok',
	paragraph: 'Bekezdés',
	quote: 'Idézet',
	code: 'Kód',
	header1: 'Címsor 1',
	header2: 'Címsor 2',
	header3: 'Címsor 3',
	header4: 'Címsor 4',
	format: 'Formátum',
	bold:  'Félkövér',
	italic: 'Dőlt',
	superscript: 'Felső index',
	strikethrough: 'Áthúzott',
	fontcolor: 'Szöveg szine',
	backcolor: 'Szöveg hátterének szine',
	removeformat: 'Formátum eltávolítása',
	cleanstyles: 'Stilusok törlése',
	lists: 'Listák',
	unorderedlist: 'Nem számozott lista',
	orderedlist: 'Számozott lista',	
	outdent: 'Outdent',
	indent: 'Indent',
	redo: 'Újra',
	undo: 'Visszavonás',
	cut: 'Kivágás',
	cancel: 'Mégsem',	
	insert: 'Beszurás',
	save: 'Mentés',	
	_delete: 'Törlés',
	insert_table: 'Táblázat beszúrása',		
	insert_row_above: 'Sor beszúrása az aktuális sor fölé',
	insert_row_below: 'Sor beszúrása ez alá',
	insert_column_left: 'Oszlop beszúrása ettöl balra',
	insert_column_right: 'Oszlop hozzáadása ettöl jobbra',									
	delete_column: 'Oszlop törlése',									
	delete_row: 'Sor törlése',									
	delete_table: 'Táblázat törlése',
	Rows: 'Sorok',
	Columns: 'Oszlopok',	
	add_head: 'Fejrész hozzáadása',
	delete_head: 'Fejrész törlése',	
	title: 'Felira',
	image_view: 'Kép megnézése',
	image_position: 'Pozició',
	none: 'nincs',
	left: 'bal',
	right: 'jobb',
	image_web_link: 'Link a képre',
	text: 'Szöveg',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Videó embed code',
	file: 'File',	
	upload: 'Feltöltés',
	download: 'Letöltés',
	choose: 'Válassz',
	or_choose: 'Vagy válassz',
	drop_file_here: 'Ide dobd a file-t',
	align_left:	'Balra igazítás',	
	align_center: 'Középre igazítás',
	align_right: 'Jobbra igazítás',
	align_justify: 'Sorkizárt',
	horizontalrule: 'Horizontális vonal',
	fullscreen: 'Teljes képernyős',
	deleted: 'Törölt',
	none: 'Nincs',
	anchor: 'Horgony'
};
