var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Imagen',
	table: 'Tabla',
	link: 'Enlace',
	link_insert: 'Insertar enlace ...',
	unlink: 'Desenlazar',
	styles: 'Estilos',
	paragraph: 'Párrafo',
	quote: 'Comillas',
	code: 'Código',
	header1: 'Cabecera 1',
	header2: 'Cabecera 2',
	header3: 'Cabecera 3',
	header4: 'Cabecera 4',
	format: 'Formato',
	bold:  'Negrita',
	italic: 'Itálica',
	superscript: 'Superindice',
	strikethrough: 'Tachado',
	fontcolor: 'Color fuente',
	backcolor: 'Color fondo',
	removeformat: 'Elimar formato',
	cleanstyles: 'Limpiar estilos',
	lists: 'Listas',
	unorderedlist: 'Lista sin orden',
	orderedlist: 'Lista ordenada',	
	outdent: 'Disminuir sangrado',
	indent: 'Sangrar',
	redo: 'Rehacer',
	undo: 'Deshacer',
	cut: 'Cortar',
	cancel: 'Cancelar',	
	insert: 'Añadir',
	save: 'Guardar',	
	_delete: 'Borrar',
	insert_table: 'Añadir tabla',		
	insert_row_above: 'Añadir fila arriba',
	insert_row_below: 'Añadir fila debajo',
	insert_column_left: 'Añadir columna a la izquierda',
	insert_column_right: 'Añadir column a la derecha',									
	delete_column: 'Borrar columna',									
	delete_row: 'Borrar fila',									
	delete_table: 'Borrar tabla',
	Rows: 'Filas',
	Columns: 'Columnas',	
	add_head: 'Añadir cabecera',
	delete_head: 'Borrar cabecera',	
	title: 'Título',
	image_view: 'Ver imagen',
	image_position: 'Posición',
	none: 'ninguna',
	left: 'izquierda',
	right: 'derecha',
	image_web_link: 'Enlace de imagen web',
	text: 'Texto',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Código embebido del video',
	file: 'Fichero',	
	upload: 'Cargar',
	download: 'Descargar',
	choose: 'Seleccionar',
	or_choose: 'O seleccionar',
	drop_file_here: 'Soltar el fichero aquí',
	align_left:	'Alinear a la izquierda',	
	align_center: 'Alinear al centro',
	align_right: 'Alinear a la derecha',
	align_justify: 'Justificar',
	horizontalrule: 'Trazo horizontal',
	fullscreen: 'Pantalla completa',
	deleted: 'Borrado',
	none: 'Ninguno',
	anchor: 'Anclaje o anchor'
};