var RLANG = {
	html: 'Code HTML',
	video: 'Vidéo',
	image: 'Image',
	table: 'Tableau',
	link: 'Lien URL',
	link_insert: 'Insérer un lien',
	unlink: 'Nétoyer le lien',
	styles: 'Styles',
	paragraph: 'Paragraphe',
	quote: 'Citation',
	code: 'Code',
	header1: 'Titre 1',
	header2: 'Titre 2',
	header3: 'Titre 3',
	header4: 'Titre 4',
	format: 'Format',
	bold:  'Gras',
	italic: 'Italique',
	superscript: 'Diacritique',
	strikethrough: 'Rayé',
	fontcolor: 'Couleur du texte',
	backcolor: 'Couleur du fond de ligne',
	removeformat: 'Nétoyer le format',
	lists: 'Listes',
	unorderedlist: 'Liste à puce',
	orderedlist: 'Liste numérotée',
	outdent: 'Diminuer l\'alinéa',
	indent: 'Augmenter l\'alinéa',
	redo: 'Refaire',
	undo: 'Défaire',
	cut: 'Couper',
	cancel: 'Annuler',
	insert: 'Insérer',
	save: 'Sauvegarder',
	_delete: 'Supprimer',
	insert_table: 'Insérer le tableau',
	insert_row_above: 'Ajouter une ligne au dessus',
	insert_row_below: 'Ajouter une ligne en dessous',
	insert_column_left: 'Ajouter une colonne à gauche',
	insert_column_right: 'Ajouter une colonne à droite',
	delete_column: 'Supprimer la colonne',
	delete_row: 'Supprimer la ligne',
	delete_table: 'Supprimer le tableau',
	Rows: 'Lignes ',
	Columns: 'Colonnes',
	add_head: 'Ajouter un titre',
	delete_head: 'Supprimer le titre',
	title: 'Titre',
	image_view: 'Voir l\'image',
	image_position: 'Position de l\'image',
	none: 'aucun',
	left: 'à gauche',
	right: 'à droite',
	image_web_link: 'lien de l’image',
	text: 'Texte',
	mailto: 'Envoyer à ',
	web: 'URL',
	video_html_code: 'Code HTML de la vidéo',
	file: 'Fichier',
	upload: 'Envoyer',
	download: 'Télécharger',
	choose: 'Choisir',
	or_choose: 'ou',
	drop_file_here: 'Glissez-déposez le fichier ici',
	align_left:	'Aligenr à gauche',
	align_center: 'Aligner au centre',
	align_right: 'Aligner à droite',
	align_justify: 'Justifier',
	horizontalrule: 'Ligne horizontale',
	fullscreen: 'Plein écran',
	deleted: 'Supprimer',
	none: 'aucun'
};