var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Afbeelding',
	table: 'Tabel',
	link: 'Link',
	link_insert: 'Link invoegen...',
	unlink: 'Link ontkoppelen',
	styles: 'Stijlen',
	paragraph: 'Paragraaf',
	quote: 'Citaat',
	code: 'Code',
	header1: 'Kop 1',
	header2: 'Kop 2',
	header3: 'Kop 3',
	header4: 'Kop 4',
	format: 'Format',
	bold:  'Vet',
	italic: 'Cursief',
	superscript: 'Superscript',
	strikethrough: 'Doorstrepen',
	fontcolor: 'Tekstkleur',
	backcolor: 'Achtergrondkleur',
	removeformat: 'Verwijder formattering',
	cleanstyles: 'Stijlen opschonen',
	lists: 'Lijsten',
	unorderedlist: 'Ongeordende lijst',
	orderedlist: 'Geordende lijst',	
	outdent: 'Uitspringen',
	indent: 'Inspringen',
	redo: 'Opnieuw maken',
	undo: 'Ongedaan maken',
	cut: 'Knippen',
	cancel: 'Annuleren',	
	insert: 'Invoegen',
	save: 'Opslaan',	
	_delete: 'Verwijderen',
	insert_table: 'Tabel invoegen',		
	insert_row_above: 'Rij hierboven invoegen',
	insert_row_below: 'Rij hieronder invoegen',
	insert_column_left: 'Kolom links toevoegen',
	insert_column_right: 'Kolom rechts toevoegen',									
	delete_column: 'Verwijder kolom',									
	delete_row: 'Verwijder rij',									
	delete_table: 'Verwijder tabel',
	Rows: 'Rijen',
	Columns: 'Kolommen',	
	add_head: 'Titel toevoegen',
	delete_head: 'Titel verwijderen',	
	title: 'Titel',
	image_view: 'Toon afbeelding',
	image_position: 'Positie',
	none: 'geen',
	left: 'links',
	right: 'rechts',
	image_web_link: 'Afbeelding link',
	text: 'Tekst',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Video embed code',
	file: 'Bestand',	
	upload: 'Uploaden',
	download: 'Downloaden',
	choose: 'Kies',
	or_choose: 'Of kies',
	drop_file_here: 'Sleep bestand hier',
	align_left:	'Links uitlijnen',	
	align_center: 'Centreren',
	align_right: 'Rechts uitlijnen',
	align_justify: 'Uitvullen',
	horizontalrule: 'Horizontale lijn',
	fullscreen: 'Volledig scherm',
	deleted: 'Verwijderd',
	none: 'Geen',
	anchor: 'Anker'
};
