var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Görsel',
	table: 'Tablo',
	link: 'Bağlantı',
	link_insert: 'Bağlantı Ekle ...',
	unlink: 'Bağlantı Kaldır',
	styles: 'Stiller',
	paragraph: 'Paragraf',
	quote: 'Alıntı',
	code: 'Kod',
	header1: 'Başlık 1',
	header2: 'Başlık 2',
	header3: 'Başlık 3',
	header4: 'Başlık 4',
	format: 'Biçim',
	bold:  'Kalın',
	italic: 'Eğik',
	superscript: 'Üst simge',
	strikethrough: 'Üstü çizili',
	fontcolor: 'Yazı rengi',
	backcolor: 'Arkaplan rengi',
	removeformat: 'Biçimi kaldır',
	cleanstyles: 'Stilleri temizle',
	lists: 'Listeler',
	unorderedlist: 'Sırasız liste',
	orderedlist: 'Sıralı liste',	
	outdent: 'Girintiyi azalt',
	indent: 'Girintiyi artır',
	redo: 'Yeniden yap',
	undo: 'Geri al',
	cut: 'Kes',
	cancel: 'İptal',	
	insert: 'Ekle',
	save: 'Kaydet',	
	_delete: 'Sil',
	insert_table: 'Tablo ekle',		
	insert_row_above: 'Yukarı satır ekle',
	insert_row_below: 'Alta satır ekle',
	insert_column_left: 'Sola sütun ekle',
	insert_column_right: 'Sağa sütun ekle',									
	delete_column: 'Sütun sil',									
	delete_row: 'Satır sil',									
	delete_table: 'Tablo sil',
	Rows: 'Satırlar',
	Columns: 'Sütunlar',	
	add_head: 'Başlık ekle',
	delete_head: 'Başlık sil',	
	title: 'Başlık',
	image_view: 'Görseli göster',
	image_position: 'Pozisyon',
	none: 'hiçbiri',
	left: 'sol',
	right: 'sağ',
	image_web_link: 'Görselin web bağlantısı',
	text: 'Yazı',
	mailto: 'E-Posta',
	web: 'URL',
	video_html_code: 'Video embed kodu',
	file: 'Dosya',	
	upload: 'Yükle',
	download: 'İndir',
	choose: 'Seç',
	or_choose: 'Veya seç',
	drop_file_here: 'Dosyayı buraya bırak',
	align_left:	'Sola hizala',	
	align_center: 'Ortala',
	align_right: 'Sağa hizala',
	align_justify: 'Satır uzunluğuna ayarla',
	horizontalrule: 'Yatay çizgi',
	fullscreen: 'Tam ekran',
	deleted: 'Silindi',
	none: 'Hiçbiri',
	anchor: 'Çapa'
};
