html {
	padding: 0;
	margin: 0;
}
body {
	font-family: Helvetica, Arial, Verdana, Tahoma, sans-serif;      
	font-size: 15px;
	margin: 0;
	padding: 0;
	overflow-x: hidden;
	background: #f4f4f4;
}
#page {
	max-width: 900px;
	width: 74%;
	margin: 20px auto;	
	padding: 15px 50px;
	background: #fff;
	border: 1px solid #ddd;
}
#page:focus {
	outline: none;
}

::selection {
	background-color: #333;
	color: #fff;
	text-shadow: none;
}

div,
p,
ul,
ol,
table,
dl,
blockquote,
pre,
iframe, 
object,
hr {
	margin-bottom: 15px;	
	line-height: 1.5em;		
}
blockquote {
	margin-left: 3em;
	font-style: italic;
	color: #777;	
}
ul, ol {
	padding-left: 2em;	
}
ul ul, 
ol ol, 
ul ol, 
ol ul {
	border: none;
	margin: 2px !important;
	padding: 0;
	padding-left: 2em;	
}
dl dt { font-weight: bold; }
dd { margin-left: 1em;}

table {
	border-collapse: collapse;
	font-size: 1em;	
}
table td {
	border: 1px solid #ddd;
	padding: 5px;
}
table thead td {
	border-bottom: 2px solid #000 !important;
	font-weight: bold;
}
code, pre {
	font-family: monospace sans-serif; 
}
code {
	background-color: #d8d7d7;
}
pre { 
	padding: 1em; 
	border: 1px dashed #ccc; 
	background: #f5f5f5; 
	overflow: auto;  
}
hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #ccc;
}

h1, h2, h3, h4,h5 {
	font-weight: bold;	
}

h1 {
	font-size: 36px;
	line-height: 40px;
	margin-bottom: 10px;	
}
h2 {
	font-size: 30px;
	line-height: 36px;	
	margin-bottom: 15px;	
}
h3 {
	font-size: 24px;
	line-height: 30px;	
	margin-bottom: 10px;	
}
h4 {
	font-size: 18px;
	line-height: 24px;	
	margin-bottom: 10px;	
}
h4 {
	font-size: 1em;
	margin-bottom: 10px;	
}
