var RLANG = {
	html: 'HTML',
	video: 'Video',
	image: 'Obrázek',
	table: 'Tabulka',
	link: 'Odkaz',
	link_insert: 'Vložit odkaz ...',
	unlink: 'Odstranit odkaz',
	styles: 'Styly',
	paragraph: 'Odstavec',
	quote: 'Citace',
	code: 'Kód',
	header1: 'Nadpis 1',
	header2: 'Nadpis 2',
	header3: 'Nadpis 3',
	header4: 'Nadpis 4',
	format: 'Formát',
	bold:  'Tučné',
	italic: 'Kurzíva',
	superscript: 'Horní index',
	strikethrough: 'Přeškrtnuté',
	fontcolor: 'Barva písma',
	backcolor: 'Barva pozadí',
	removeformat: 'Odstranit formátování',
	cleanstyles: 'Odstranit styly',
	lists: 'Seznamy',
	unorderedlist: 'Seznam s odrážkami',
	orderedlist: 'Číslovaný seznam',	
	outdent: 'Zmenšit odsazení',
	indent: 'Zvětšit odsazení',
	redo: 'Vpřed',
	undo: 'Zpět',
	cut: 'Vyjmout',
	cancel: 'Zrušit',	
	insert: 'Vložit',
	save: 'Uložit',	
	_delete: 'Smazat',
	insert_table: 'Vložit tabulku',		
	insert_row_above: 'Přidat řádek nahoru',
	insert_row_below: 'Přidat řádek dolu',
	insert_column_left: 'Přidat sloupec vlevo',
	insert_column_right: 'Přidat sloupec vpravo',									
	delete_column: 'Smazat sloupec',									
	delete_row: 'Smazat řádek',									
	delete_table: 'Smazat tabulku',
	Rows: 'Řádky',
	Columns: 'Sloupce',	
	add_head: 'Přidat záhlaví',
	delete_head: 'Smazat záhlaví',	
	title: 'Titulek',
	image_view: 'Zobrazit obrázek',
	image_position: 'Pozice',
	none: 'žádný',
	left: 'vlevo',
	right: 'vpravo',
	image_web_link: 'Odkaz na obrázek',
	text: 'Text',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Kód pro vložení videa na stránku',
	file: 'Soubor',	
	upload: 'Nahrát',
	download: 'Stáhnout',
	choose: 'Vybrat',
	or_choose: 'nebo',
	drop_file_here: 'Přetáhněte soubor zde',
	align_left:	'Zarovnat vlevo',	
	align_center: 'Zarovnat na střed',
	align_right: 'Zarovnat vpravo',
	align_justify: 'Zarovnat do bloku',
	horizontalrule: 'Vodorovná  čára',
	fullscreen: 'Celá obrazovka',
	deleted: 'Přeškrtnuté',
	none: 'Žádná',
	anchor: 'Záložka'
};
