//@chen1706@gmail.com
var RLANG = {
	html: 'HTML代码',
	video: '视频',
	image: '图片',
	table: '表格',
	link: '链接',
	link_insert: '插入链接',
	unlink: '取消链接',
	styles: '样式',
	paragraph: '段落',
	quote: '引用',
	code: '代码',
	header1: '一级标题',
	header2: '二级标题',
	header3: '三级标题',
	header4: '四级标题',
	format: '格式',
	bold:  '粗体',
	italic: '斜体',
	superscript: '上标',
	strikethrough: '删除线',
	fontcolor: '字体颜色',
	backcolor: '背景颜色',
	removeformat: '取消格式',
	cleanstyles: '清除样式',
	lists: '目录',
	unorderedlist: '项目编号',
	orderedlist: '数字编号',	
	outdent: '减少缩进',
	indent: '增加缩进',
	redo: '重做',
	undo: '撤销',
	cut: '剪切',
	cancel: '取消',	
	insert: '插入',
	save: '保存',	
	_delete: '删除',
	insert_table: '插入表格',		
	insert_row_above: '在上方插入',
	insert_row_below: '在下方插入',
	insert_column_left: '在左侧插入',
	insert_column_right: '在右侧插入',									
	delete_column: '删除整列',									
	delete_row: '删除整行',									
	delete_table: '删除表格',
	Rows: '行',
	Columns: '列',	
	add_head: '添加标题',
	delete_head: '删除标题',	
	title: '标题',
	image_view: '查看图片',
	image_position: '位置',
	none: '无',
	left: '左',
	right: '右',
	image_web_link: '图片网页链接',
	text: '文本',
	mailto: '邮箱',
	web: '网址',
	video_html_code: '视频嵌入代码',
	file: '文件',	
	upload: '上传',
	download: '下载',
	choose: '选择',
	or_choose: '或选择',
	drop_file_here: '将文件拖拽至此区域',
	align_left:	'左对齐',	
	align_center: '居中',
	align_right: '右对齐',
	align_justify: '两端对齐',
	horizontalrule: '水平线',
	fullscreen: '全屏',
	deleted: '删除',
	none: '无',
	anchor: '锚点'
};
