var RLANG = {
	html: 'Код',
	video: 'Відео',
	image: 'Зображення',
	table: 'Таблиця',
	link: 'Посилання',
	link_insert: 'Вставити посилання ...',
	unlink: 'Видалити посилання',
	styles: 'Стилі',
	paragraph: 'Звичайний текст',
	quote: 'Цитата',
	code: 'Код',
	header1: 'Заголовок 1',
	header2: 'Заголовок 2',
	header3: 'Заголовок 3',
	header4: 'Заголовок 4',
	format: 'Формат',
	bold:  'Жирний',
	italic: 'Похилий',
	superscript: 'Надрядковий',
	strikethrough: 'Закреслений',
	fontcolor: 'Колір тексту',
	backcolor: 'Заливка тексту',
	removeformat: 'Видалити формат',
	cleanstyles: 'Видалити стилі MS Word',
	lists: 'Списки',
	unorderedlist: 'Звичайний список',
	orderedlist: 'Нумерований список',
	outdent: 'Зменшити відступ',
	indent: 'Збільшити відступ',
	redo: 'Повтор',
	undo: 'Скасування',
	cut: 'Кат / Врізка',
	cancel: 'Скасувати',
	insert: 'Вставити',
	save: 'Зберегти',
	_delete: 'Видалити',
	insert_table: 'Вставити таблицю',
	insert_row_above: 'Додати рядок зверху',
	insert_row_below: 'Додати рядок знизу',
	insert_column_left: 'Додати стовпець ліворуч',
	insert_column_right: 'Додати стовпець праворуч',
	delete_column: 'Видалити стовпець',
	delete_row: 'Видалити рядок',
	delete_table: 'Видалити таблицю',
	Rows: 'Рядки',
	Columns: 'Стовпці',
	add_head: 'Додати заголовок',
	delete_head: 'Видалити заголовок',
	title: 'Підказка',
	image_view: 'Завантажити зображення',
	image_position: 'Обтікання текстом',
	none: 'ні',
	left: 'ліворуч',
	right: 'праворуч',
	image_web_link: 'Посилання на зображення',
	text: 'Текст',
	mailto: 'Ел. пошта',
	web: 'URL',
	video_html_code: 'Код відео ролика',
	file: 'Файл',
	upload: 'Вивантажити',
	download: 'Завантажити',
	choose: 'Вибрати',
	or_choose: 'Або виберіть',
	drop_file_here: 'Перенесіть файл сюди',
	align_left:	'По лівому краю',
	align_center: 'По центру',
	align_right: 'По правому краю',
	align_justify: 'Вирівняти текст по ширині',
	horizontalrule: 'Горизонтальна лінійка',
	fullscreen: 'На весь екран',
	deleted: 'Видалений',
	none: 'Немає',
	anchor: 'Якір'
};
