var RLANG = {
	html: 'Ver HTML',
	video: 'V&iacute;deo',
	image: 'Imagem',
	table: 'Tabela',
	link: 'Link',
	link_insert: 'Inserir link...',
	unlink: 'Remover link',
	styles: 'Estilos',
	paragraph: 'Par&aacute;grafo',
	quote: 'Cita&ccedil;&atilde;o',
	code: 'C&oacute;digo',
	header1: 'T&iacute;tulo 1',
	header2: 'T&iacute;tulo 2',
	header3: 'T&iacute;tulo 3',
	header4: 'T&iacute;tulo 4',	
	format: 'Formato',
	bold:  'Negrito',
	italic: 'It&aacute;lico',
	superscript: 'Sobrescrito',
	strikethrough: 'Taxado',
	fontcolor: 'Cor da fonte',
	backcolor: 'Cor do fundo',
	removeformat: 'Remover formato',
	cleanstyles: 'Limpar estilos',
	lists: 'Listas',
	unorderedlist: 'Lista n&atilde;o ordenada',
	orderedlist: 'Lista ordenada',	
	outdent: 'Remover identa&ccedil;&atilde;o',
	indent: 'Identar',
	redo: 'Refazer',
	undo: 'Voltar',
	cut: 'Inserir divis&atilde;o',
	cancel: 'Cancelar',	
	insert: 'Inserir',
	save: 'Salvar',	
	_delete: 'Remover',
	insert_table: 'Inserir tabela',	
	add_cell: 'Adicionar coluna',
	delete_cell: 'Remover coluna',
	add_row: 'Adicionar linha',
	delete_row: 'Remover linha',
	thead: 'Cabe&ccedil;alho',
	delete_table: 'Remover tabela',	
	insert_row_above: 'Adicionar linha acima',
	insert_row_below: 'Adicionar linha abaixo',
	insert_column_left: 'Adicionar coluna à esquerda',
	insert_column_right: 'Adicionar coluna da direita',									
	delete_column: 'Remover Coluna',									
	delete_row: 'Remover linha',								
	delete_table: 'Remover tabela',	
	Rows: 'Linhas',
	Columns: 'Colunas',	
	add_head: 'Adicionar cabeçalho',
	delete_head: 'Remover cabeçalho',		
	title: 'T&iacute;tulo',
	image_view: 'Visualizar imagem',
	image_position: 'Posi&ccedil;&atilde;o',
	none: 'nenhum',
	left: 'esquerda',
	right: 'direita',
	image_web_link: 'link para uma imagem',
	text: 'Texto',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Video embed code',
	file: 'Arquivo',		
	upload: 'Upload',
	download: 'Download',
	choose: 'Escolha',
	or_choose: 'Ou escolha',
	drop_file_here: 'Arraste um arquivo até aqui',
	align_left:	'Alinhar a esquerda',	
	align_center: 'Centralizar',
	align_right: 'Alinhar a direita',
	align_justify: 'Justificar',
	horizontalrule: 'Linha horizontal',
	fullscreen: 'Tela cheia',
	deleted: 'Removido',
	none: 'Nenhum'								
};
