var RLANG = {
    html: 'Код',
    video: 'Відэа',
    image: 'Малюнак',
    table: 'Табліца',
    link: 'Спасылка',
    link_insert: 'Уставіць спасылку ...',
    unlink: 'Выдаліць спасылку',
    styles: 'Стылі',
    paragraph: 'Звычайны тэкст',
    quote: 'Цытата',
    code: 'Код',
    header1: 'Загаловак 1',
    header2: 'Загаловак 2',
    format: 'Фармат',
    bold: 'Паўтлусты',
    italic: 'Нахільны',
    superscript: 'Надрадковы',
    strikethrough: 'Закрэслены',
    fontcolor: 'Колер тэксту',
    backcolor: 'Заліванне тэксту',
    removeformat: 'Выдаліць фармат',
    cleanstyles: 'Выдаліць стылі MS Word',
    lists: 'Спісы',
    unorderedlist: 'Звычайны спіс',
    orderedlist: 'Нумараваны спіс',
    outdent: 'Паменьшыць водступ',
    indent: 'Павялічыць водступ',
    redo: 'Паўтор',
    undo: 'Адмена',
    cut: 'Кат / Урэзка',
    cancel: 'Адмяніць',
    insert: 'Уставіць',
    save: 'Захаваць',
    _delete: 'Выдаліць',
    insert_table: 'Уставіць табліцу',
    insert_row_above: 'Дадаць радок зверху',
    insert_row_below: 'Дадаць радок знізу',
    insert_column_left: 'Дадаць слупок злева',
    insert_column_right: 'Дадаць слупок справа',
    delete_column: 'Выдаліць слупок',
    delete_row: 'Выдаліць радок',
    delete_table: 'Выдаліць табліцу',
    Rows: 'Радкі',
    Columns: 'Стаўбцы',
    add_head: 'Дадаць загаловак',
    delete_head: 'Выдаліць загаловак',
    title: 'Падказка',
    image_view: 'Запампаваць малюнак',
    image_position: 'Абцяканне тэкстам',
    none: 'Няма',
    left: 'Злева',
    right: 'Справа',
    image_web_link: 'Спасылка на малюнак',
    text: 'Тэкст',
    mailto: 'Эл. пошта ',
    web: 'URL',
    video_html_code: 'Код відэа роліка',
    file: 'Файл',
    upload: 'Загрузіць',
    download: 'Запампаваць',
    choose: 'Выбраць',
    or_choose: 'Ці іншае',
    drop_file_here: 'Перацягніце файл сюды',
    align_left: 'Па левым краі',
    align_center: 'Па цэнтры',
    align_right: 'Па правым краі',
    align_justify: 'Выраўнаваць тэкст па шырыні',
    horizontalrule: 'Гарызантальная лінейка',
    fullscreen: 'Ва ўвесь экран',
    deleted: 'Закрэслены'
};