var RLANG = {
	html: 'HTML',
	video: 'ビデオ',
	image: 'イメージ',
	table: 'テーブル',
	link: 'リンク',
	link_insert: 'リンクの挿入 ...',
	unlink: 'リンクを外す',
	styles: 'スタイル',
	paragraph: '段落',
	quote: '引用',
	code: 'コード',
	header1: 'ヘッダー 1',
	header2: 'ヘッダー 2',
	header3: 'ヘッダー 3',
	header4: 'ヘッダー 4',
	format: 'フォーマット',
	bold:  '太字',
	italic: 'イタリック',
	superscript: '上付き文字',
	strikethrough: '取り消し線',
	fontcolor: 'フォント色',
	backcolor: '背景色',
	removeformat: 'フォーマットの解除',
	cleanstyles: 'スタイルのクリヤー',
	lists: 'リスト',
	unorderedlist: '番号なしリスト',
	orderedlist: '番号つきリスト',	
	outdent: '字上げ（逆インデント）',
	indent: '字下げ（インデント）',
	redo: '再実行',
	undo: '元に戻す',
	cut: 'カット',
	cancel: 'キャンセル',	
	insert: '挿入',
	save: '保存',	
	_delete: '削除',
	insert_table: 'テーブルの挿入',		
	insert_row_above: '列を上に追加',
	insert_row_below: '列を下に追加',
	insert_column_left: '行を左に追加',
	insert_column_right: '行を右に追加',									
	delete_column: '行を削除',									
	delete_row: '列を削除',									
	delete_table: 'テーブルを削除',
	Rows: '列',
	Columns: '行',	
	add_head: 'テーブルヘッダの追加',
	delete_head: 'テーブルヘッダの削除',	
	title: 'タイトル',
	image_view: 'イメージを見る',
	image_position: 'イメージの位置',
	none: '無し',
	left: '左',
	right: '右',
	image_web_link: 'イメージへのリンク',
	text: 'テキスト',
	mailto: 'メール',
	web: 'URL',
	video_html_code: 'ビデオ埋め込みコード',
	file: 'ファイル',	
	upload: 'アップロード',
	download: 'ダウンロード',
	choose: '選択',
	or_choose: 'または選択',
	drop_file_here: 'ファイルをここにドロップ',
	align_left:	'左揃え',	
	align_center: '中央揃え',
	align_right: '右揃え',
	align_justify: '均等割り付け',
	horizontalrule: '水平線',
	fullscreen: '全画面',
	deleted: '打消し',
	none: '無し',
	anchor: 'アンカー'
};